Learn R Programming

OnboardClient (version 1.0.0)

get_building_info: Building Info

Description

Retrieves building id(s) and name(s). Assigns each to list variables in the parent environment called "id" and "name", and prints each list.

Usage

get_building_info(buildings, verbose = TRUE)

Value

A data.frame of building info with two columns, 'id' and 'name'.

Arguments

buildings

Integer, character, or vectors of those types, providing building id(s) or name(s). You can provide multiple buildings at once.

verbose

Logical. If TRUE (default), print status messages.