Learn R Programming

OnboardClient (version 1.0.0)

get_equipment_by_ids: Equipment by ID

Description

Queries equipment by their ids.

Usage

get_equipment_by_ids(id)

Value

A data.frame of the requested equipment, or an empty list if no equipment matches those ids.

Arguments

id

Integer or integer vector, containing one or many equipment ids.

Examples

Run this code
if (FALSE) {
equipment <- get_equipment_by_ids(c(1000,1001))

# If you are using the point selector function:
query <- PointSelector()

query$buildings <- 101
query$equipment_types <- 'ahu'

selection <- select_points(query)

equipment <- get_equipment_by_ids(selection$equipment)
}

Run the code above in your browser using DataLab