Retrieves building id(s) and name(s). Assigns each to list variables in the parent environment called "id" and "name", and prints each list.
get_building_info(buildings, verbose = TRUE)A data.frame of building info with two columns, 'id' and 'name'.
Integer, character, or vectors of those types, providing building id(s) or name(s). You can provide multiple buildings at once.
Logical. If TRUE (default), print status messages.